Stan Math Library: stan/math/prim/mat/fun/append_row.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
append_row.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/scal/meta/return_type.hpp>`
`#include <stan/math/prim/scal/err/check_size_match.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , typename T2 , int R1, int C1, int R2, int C2>
Eigen::Matrix< typename return_type< T1, T2 >::type, Eigen::Dynamic, Eigen::Dynamic > | stan::math::append_row (const Eigen::Matrix< T1, R1, C1 > &A, const Eigen::Matrix< T2, R2, C2 > &B)
| Return the result of stacking the rows of the first argument matrix on top of the second argument matrix. More...
template<typename T1 , typename T2 , int R1, int R2>
Eigen::Matrix< typename return_type< T1, T2 >::type, Eigen::Dynamic, 1 > | stan::math::append_row (const Eigen::Matrix< T1, R1, 1 > &A, const Eigen::Matrix< T2, R2, 1 > &B)
| Return the result of stacking the first vector on top of the second vector, with the result being a vector. More...
template<typename T , int R1, int C1, int R2, int C2>
Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > | stan::math::append_row (const Eigen::Matrix< T, R1, C1 > &A, const Eigen::Matrix< T, R2, C2 > &B)
| Return the result of stacking the rows of the first argument matrix on top of the second argument matrix. More...
template<typename T , int R1, int R2>
Eigen::Matrix< T, Eigen::Dynamic, 1 > | stan::math::append_row (const Eigen::Matrix< T, R1, 1 > &A, const Eigen::Matrix< T, R2, 1 > &B)
| Return the result of stacking the first vector on top of the second vector, with the result being a vector. More...
template<typename T1 , typename T2 , int R, int C>
Eigen::Matrix< typename return_type< T1, T2 >::type, Eigen::Dynamic, 1 > | stan::math::append_row (const T1 &A, const Eigen::Matrix< T2, R, C > &B)
| Return the result of stacking an scalar on top of the a vector, with the result being a vector. More...
template<typename T1 , typename T2 , int R, int C>
Eigen::Matrix< typename return_type< T1, T2 >::type, Eigen::Dynamic, 1 > | stan::math::append_row (const Eigen::Matrix< T1, R, C > &A, const T2 &B)
| Return the result of stacking a vector on top of the an scalar, with the result being a vector. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.